==> bxParty-0.2.5.zip: bxParty/xoops_version.php <==
<?php
/**
@file
@brief xoops  module ե
@author minahito
*/



$modversion['name'] = _MI_BXPARTY_NAME;
$modversion['version'] = 0.25;
$modversion['description'] = _MI_BXPARTY_DESC;

$modversion['credits'] = "minahito";
$modversion['author'] = "minahito" ;
$modversion['license'] = "GPL see LICENSE";
$modversion['official'] = 0;
$modversion['image'] = "images/bxParty.gif";
$modversion['dirname'] = "bxParty";


// Template
$modversion['use_smarty'] = 1;
$modversion['templates'][0]['file'] = 'bxparty_index.html';
$modversion['templates'][0]['description'] = '';
$modversion['templates'][1]['file'] = 'bxparty_detail.html';
$modversion['templates'][1]['description'] = '';


// Block
$modversion['blocks'][1]['file'] = "bxparty_newparty.php";
$modversion['blocks'][1]['name'] = _MI_BXPARTY_BNAME1;
$modversion['blocks'][1]['show_func'] = "b_bxparty_newparty_show";
$modversion['blocks'][1]['options'] = "10|0";
$modversion['blocks'][1]['edit_func'] = "b_bxparty_newparty_edit";
$modversion['blocks'][1]['template'] = 'bxparty_block_newparty.html';

$modversion['blocks'][2]['file'] = "bxparty_newentry.php";
$modversion['blocks'][2]['name'] = _MI_BXPARTY_BNAME2;
$modversion['blocks'][2]['show_func'] = "b_bxparty_newentry_show";
$modversion['blocks'][2]['options'] = "10|1";
$modversion['blocks'][2]['edit_func'] = "b_bxparty_newentry_edit";
$modversion['blocks'][2]['template'] = 'bxparty_block_newentry.html';


// Sql
$modversion['sqlfile']['mysql'] = "sql/mysql.sql";

$modversion['tables'][0] = "bxparty";
$modversion['tables'][1] = "bxparty_entry";
$modversion['tables'][2] = "bxparty_status";

// Admin
$modversion['hasAdmin'] = 1;

$modversion['adminindex'] = "admin/index.php";
$modversion['adminmenu'] = "admin/menu.php";



// Menu
$modversion['hasMain'] = 1;
$modversion['sub'][0]['name'] = '';
$modversion['sub'][0]['url'] = 'submit.php';

?>

==> bxParty-0.27.zip: bxParty/xoops_version.php <==
<?php
/**
@file
@brief xoops  module ե
@author minahito
*/



$modversion['name'] = _MI_BXPARTY_NAME;
$modversion['version'] = 0.27;
$modversion['description'] = _MI_BXPARTY_DESC;

$modversion['credits'] = "minahito";
$modversion['author'] = "minahito" ;
$modversion['license'] = "GPL see LICENSE";
$modversion['official'] = 0;
$modversion['image'] = "images/bxParty.gif";
$modversion['dirname'] = "bxParty";


// Template
$modversion['use_smarty'] = 1;
$modversion['templates'][0]['file'] = 'bxparty_index.html';
$modversion['templates'][0]['description'] = '';
$modversion['templates'][1]['file'] = 'bxparty_detail.html';
$modversion['templates'][1]['description'] = '';


// Block
$modversion['blocks'][1]['file'] = "bxparty_newparty.php";
$modversion['blocks'][1]['name'] = _MI_BXPARTY_BNAME1;
$modversion['blocks'][1]['show_func'] = "b_bxparty_newparty_show";
$modversion['blocks'][1]['options'] = "10|0";
$modversion['blocks'][1]['edit_func'] = "b_bxparty_newparty_edit";
$modversion['blocks'][1]['template'] = 'bxparty_block_newparty.html';

$modversion['blocks'][2]['file'] = "bxparty_newentry.php";
$modversion['blocks'][2]['name'] = _MI_BXPARTY_BNAME2;
$modversion['blocks'][2]['show_func'] = "b_bxparty_newentry_show";
$modversion['blocks'][2]['options'] = "10|1";
$modversion['blocks'][2]['edit_func'] = "b_bxparty_newentry_edit";
$modversion['blocks'][2]['template'] = 'bxparty_block_newentry.html';


// Sql
$modversion['sqlfile']['mysql'] = "sql/mysql.sql";

$modversion['tables'][0] = "bxparty";
$modversion['tables'][1] = "bxparty_entry";
$modversion['tables'][2] = "bxparty_status";

// Admin
$modversion['hasAdmin'] = 1;

$modversion['adminindex'] = "admin/index.php";
$modversion['adminmenu'] = "admin/menu.php";

// Menu
$modversion['hasMain'] = 1;
$modversion['sub'][0]['name'] = '';
$modversion['sub'][0]['url'] = 'submit.php';

// Search
$modversion['hasSearch'] = 1;
$modversion['search']['file'] = "include/search.inc.php";
$modversion['search']['func'] = "bxparty_search";

?>
